@@ -4,7 +4,7 @@ package App::SFDC::Command::Deploy;
 use strict;
 use warnings;
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use Data::Dumper;
 use File::Find 'find';
@@ -68,6 +68,7 @@ option 'rollback',
 
 
 option 'runtests',
+    doc => 'Defaults to off, turn on by setting to 1',
     short => 't',
     is => 'ro',
     default => 0;
@@ -146,7 +147,8 @@ has '_result',
 
 sub _JUnitOutput {
     my $self = shift;
-    return unless $self->testoutput and $self->runtests;
+
+    return unless $self->testoutput and ($self->_result->result->{runTestsEnabled} eq 'true');
     Role::Tiny->apply_roles_to_object(
         $self->_result,
         'App::SFDC::Role::DeployResult::JUnitOutput'
@@ -178,7 +180,7 @@ App::SFDC::Command::Deploy - Deploy files to SFDC
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 OPTIONS
 
