@@ -4,7 +4,7 @@ package App::SFDC::Command::Retrieve;
 use strict;
 use warnings;
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use Data::Dumper;
 use File::HomeDir;
@@ -73,7 +73,7 @@ option 'manifest',
         }
     };
 
-my @folders;
+our @folders;
 
 has '_manifest',
     is => 'ro',
@@ -90,9 +90,15 @@ has '_manifest',
 
         $manifest->readFromFile($_) for @{$self->manifest};
 
-        $manifest->addList(
-            $self->_session->Metadata->listMetadata(@folders)
-        ) if $self->all and @folders;
+
+        if ($self->all and @folders) {
+
+            DEBUG "Searching for folder contents: " . Dumper @folders;
+
+            $manifest->addList(
+                $self->_session->Metadata->listMetadata(@folders)
+            ) 
+        }
 
         return $manifest;
     };
@@ -155,7 +161,7 @@ App::SFDC::Command::Retrieve - Retrive files from SFDC
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 OPTIONS
 
